theory question_81_6

imports Main

begin

typedecl entity
typedecl event

consts
  BottleneckEffect :: "entity ⇒ bool"
  Population :: "entity ⇒ bool"
  Event :: "entity ⇒ bool"
  Occurs :: "event ⇒ bool"
  Agent :: "event ⇒ entity ⇒ bool"
  GetsSmaller :: "event ⇒ bool"
  DueTo :: "event ⇒ entity ⇒ bool"
  ExternalMigration :: "entity ⇒ bool"
  Cause :: "event ⇒ bool"
  Patient :: "event ⇒ entity ⇒ bool"
  Triggering :: "event ⇒ bool"
  ExternalMigrationEvents :: "entity ⇒ bool"
  Linked :: "entity ⇒ entity ⇒ bool"

(* Explanation 1: Bottleneck effect occurs when a population suddenly gets much smaller due to an event. *)
axiomatization where
  explanation_1: "∀x y z e1 e2. BottleneckEffect x ∧ Population y ∧ Event z ∧ Occurs e1 ∧ Agent e1 x ∧ GetsSmaller e2 ∧ Agent e2 y ∧ DueTo e2 z"

(* Explanation 2: External migration is an event that can cause a population to suddenly get much smaller, thus triggering the bottleneck effect. *)
axiomatization where
  explanation_2: "∀x y z e1 e2 e3. ExternalMigration x ∧ Population y ∧ BottleneckEffect z ∧ Event x ∧ Cause e1 ∧ Agent e1 x ∧ Patient e1 y ∧ GetsSmaller e2 ∧ Agent e2 y ∧ Triggering e3 ∧ Agent e3 z ∧ DueTo e3 x"

(* Explanation 3: The bottleneck effect is directly linked to external migration events. *)
axiomatization where
  explanation_3: "∀x y. BottleneckEffect x ∧ ExternalMigrationEvents y ⟶ Linked x y"  

theorem hypothesis:
  assumes asm: "BottleneckEffect x ∧ ExternalMigration y"
  (* Hypothesis: Bottleneck effect can occur with external migration. *)
  shows "∃x y e. BottleneckEffect x ∧ ExternalMigration y ∧ Occurs e ∧ Agent e x ∧ Patient e y"
proof -
  from asm have "BottleneckEffect x ∧ ExternalMigration y" by simp
  then obtain e1 where e1: "Occurs e1 ∧ Agent e1 x" using explanation_1 by blast
  then have "ExternalMigration y" using explanation_2 by blast
  have conclusion: "Occurs e1 ∧ Agent e1 x ∧ Patient e1 y" using e1 `ExternalMigration y` by simp
  show ?thesis using asm conclusion by blast
qed

end
