theory question_5_1
imports Main
begin

typedecl entity
typedecl event

consts
  Pluto :: "entity ⇒ bool"
  DwarfPlanet :: "entity ⇒ bool"
  Larger :: "entity ⇒ entity ⇒ bool"
  Smaller :: "entity ⇒ entity ⇒ bool"
  OtherPlanets :: "entity ⇒ bool"
  SolarSystem :: "entity ⇒ bool"
  Orbit :: "entity ⇒ bool"
  Cleared :: "entity ⇒ bool"
  Agent :: "event ⇒ entity ⇒ bool"
  Patient :: "event ⇒ entity ⇒ bool"
  Scientists :: "entity ⇒ bool"
  OtherObjects :: "entity ⇒ bool"
  EarthsMoon :: "entity ⇒ bool"
  Compared :: "event ⇒ bool"
  Found :: "event ⇒ bool"
  Finding :: "event ⇒ bool"
  Question :: "event ⇒ bool"

(* Explanation 1: Pluto is a kind of dwarf planet. *)
axiomatization where
  explanation_1: "∀x. Pluto x ⟶ DwarfPlanet x"

(* Explanation 2: larger; bigger is the opposite of smaller. *)
axiomatization where
  explanation_2: "∀x y. Larger x y ⟷ Smaller y x"

(* Explanation 3: a dwarf planet is usually much smaller in size; in mass than other planets. *)
axiomatization where
  explanation_3: "∀x y. DwarfPlanet x ∧ OtherPlanets y ⟶ Smaller x y"

(* Explanation 4: Other planets in the solar system have cleared their orbits. *)
axiomatization where
  explanation_4: "∀x e. OtherPlanets x ∧ SolarSystem x ⟶ (∃y. Orbit y ∧ Cleared y ∧ Agent e x ∧ Patient e y)"

(* Explanation 5: pluto has not cleared its orbit. *)
axiomatization where
  explanation_5: "∀x e. Pluto x ∧ Orbit e ⟶ ¬Cleared e"

theorem hypothesis:
  (* Premise: scientists compared pluto with other objects in the solar system and found that pluto is smaller than earth's moon. *)
  assumes asm: "Scientists x ∧ Pluto y ∧ OtherObjects z ∧ SolarSystem z ∧ EarthsMoon z ∧  Compared e1 ∧ Agent e1 x ∧ Patient e1 y ∧ Patient e1 z  ∧  Found e2 ∧ Agent e2 x ∧ Patient e2 y ∧ Smaller y z "
  (* Hypothesis: The finding that the other planets are much larger than Pluto caused scientists to question whether Pluto is a planet. *)
  shows "∃x y z e1 e2. OtherPlanets x ∧ Pluto y ∧ Scientists z ∧ Larger x y ∧ Finding e1 ∧ Agent e1 z ∧ Patient e1 x ∧ Question e2 ∧ Agent e2 z ∧ Patient e2 y"
proof -
  from asm have "Pluto y" by simp
  then have "DwarfPlanet y" using explanation_1 by simp
  then have "∃x. OtherPlanets x ∧ Smaller y x" using explanation_3 by blast
  then obtain x where x: "OtherPlanets x ∧ Smaller y x" by blast
  then have "Larger x y" using explanation_2 by simp
  have "∃e. Orbit e ∧ ¬Cleared e" using explanation_5 `Pluto y` by blast
  then have "∃x e. OtherPlanets x ∧ SolarSystem x ∧ Orbit e ∧ Cleared e" using explanation_4 by blast
  then have "Finding e1 ∧ Agent e1 x ∧ Patient e1 y" using asm by blast
  have "Question e2 ∧ Agent e2 x ∧ Patient e2 y" using asm by blast
  show ?thesis using `Scientists x` `OtherPlanets x` `Pluto y` `Larger x y` `Finding e1` `Agent e1 x` `Patient e1 y` `Question e2` `Agent e2 x` `Patient e2 y` by blast
qed

end
